{% extends "admin/base_site.html" %} {% load url from future %} {% load compress i18n %} {% load staticfiles %} {% load widgy_tags %} {% block extrahead %} {{ block.super }} {% compress css %} {% endcompress %} {% compress js %}
{% endcompress %} {% endblock %} {% block content %}

# {% trans "Page History" %}

{% for commit in commits %}
1. {% block commit_info %} {{ commit.created_at|date:"SHORT_DATETIME_FORMAT" }} {% if commit.author %}{% blocktrans with author=commit.author %} by {{ author }}.{% endblocktrans %}{% endif %} {% if commit.publish_at > commit.created_at %} ( {% if not commit.is_published %} {% trans "Scheduled to be published at" %} {% else %} {% trans "Published at" %} {% endif %} {{ commit.publish_at|date:"SHORT_DATETIME_FORMAT" }}. ) {% if not commit.is_published %} * {% endif %} {% endif %} {% endblock %}
   {% block commit_actions %} {% has_add_permission site commit as can_revert %} {% if commit.root_node != commit.tracker.head.root_node and can_revert %} {% trans "Revert to this Version" %} {% elif can_revert %} {% trans "Can't revert; this is the same as the current version." %} {% endif %} {% for diff_url in commit.diff_urls %} {% trans "Diff" %} {% endfor %} {% for owner in object.owners %} {% get_action_links owner commit.root_node as links %} {% for link in links %} {{ link.text }} {% endfor %} {% endfor %} {% endblock %}
   {% if commit.message %}

   > {{ commit.message|linebreaks }}

   {% endif %}
{% endfor %}

{% endblock %}